@@ -85,6 +85,13 @@ private Q_SLOTS:
     void testZipDuplicateNames();
     void testZipWithinZip();
     void testZip64();
+    void testZipReopenWithoutDoubleDeletion();
+    void testZip64NestedStored();
+    void testZip64NestedStoredStreamed();
+    void testZip64EndOfCentralDirectory();
+    void testZip64DataDescriptor();
+    void testZip64ExtraZip64Size();
+    void testZip64ExtraZip64Offset();
 
     void testRcc();
 
@@ -121,6 +128,12 @@ private Q_SLOTS:
         setup7ZipData();
     }
     void test7ZipMaxLength();
+    void test7ZipNamelessFile();
+    void test7ZipMultipleNamelessFiles();
+    void test7ZipReadNumber();
+#if HAVE_OPENSSL_SUPPORT
+    void test7ZipPasswordProtected();
+#endif
 #endif
 
     void cleanupTestCase();
